@@ -1550,13 +1550,22 @@ cmd_gui (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
 	if (!strcasecmp (word[2], "HIDE"))
 	{
-		fe_ctrl_gui (sess, 0);
+		fe_ctrl_gui (sess, 0, 0);
 	} else if (!strcasecmp (word[2], "SHOW"))
 	{
-		fe_ctrl_gui (sess, 1);
+		fe_ctrl_gui (sess, 1, 0);
 	} else if (!strcasecmp (word[2], "FOCUS"))
 	{
-		fe_ctrl_gui (sess, 2);
+		fe_ctrl_gui (sess, 2, 0);
+	} else if (!strcasecmp (word[2], "FLASH"))
+	{
+		fe_ctrl_gui (sess, 3, 0);
+	} else if (!strcasecmp (word[2], "COLOR"))
+	{
+		fe_ctrl_gui (sess, 4, atoi (word[3]));
+	} else if (!strcasecmp (word[2], "ICONIFY"))
+	{
+		fe_ctrl_gui (sess, 5, 0);
 	} else
 	{
 		return FALSE;
@@ -2272,7 +2281,8 @@ cmd_server (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 #ifdef USE_OPENSSL
 	int use_ssl = FALSE;
 
-	if (strcmp (word[2], "-ssl") == 0)
+	/* BitchX uses -ssl, mIRC uses -e, let's support both */
+	if (strcmp (word[2], "-ssl") == 0 || strcmp (word[2], "-e") == 0)
 	{
 		use_ssl = TRUE;
 		offset++;	/* args move up by 1 word */
@@ -2338,6 +2348,15 @@ urlserv:
 		}
 	}
 
+	/* support +7000 style ports like mIRC */
+	if (port[0] == '+')
+	{
+		port++;
+#ifdef USE_OPENSSL
+		use_ssl = TRUE;
+#endif
+	}
+
 	if (*pass)
 	{
 		safe_strcpy (serv->password, pass, sizeof (serv->password));
@@ -2631,7 +2650,7 @@ const struct commands xc_cmds[] = {
 	 N_("GATE <host> [<port>], proxies through a host, port defaults to 23")},
 	{"GETINT", cmd_getint, 0, 0, "GETINT <default> <command> <prompt>"},
 	{"GETSTR", cmd_getstr, 0, 0, "GETSTR <default> <command> <prompt>"},
-	{"GUI", cmd_gui, 0, 0, "GUI [SHOW|HIDE|FOCUS]"},
+	{"GUI", cmd_gui, 0, 0, "GUI [SHOW|HIDE|FOCUS|FLASH|ICONIFY|COLOR <n>]"},
 	{"HELP", cmd_help, 0, 0, 0},
 	{"HOP", cmd_hop, 1, 1,
 	 N_("HOP <nick>, gives chanhalf-op status to the nick (needs chanop)")},
@@ -2654,7 +2673,7 @@ const struct commands xc_cmds[] = {
 	 N_("LAGCHECK, forces a new lag check")},
 	{"LASTLOG", cmd_lastlog, 0, 0,
 	 N_("LASTLOG <string>, searches for a string in the buffer")},
-	{"LIST", cmd_list, 1, 0, ""},
+	{"LIST", cmd_list, 1, 0, 0},
 	{"LOAD", cmd_load, 0, 0, N_("LOAD <file>, loads a plugin or script")},
 
 	{"MDEHOP", cmd_mdehop, 1, 1,
@@ -2718,7 +2737,7 @@ const struct commands xc_cmds[] = {
 	 N_("SERVER <host> [<port>] [<password>], connects to a server, the default port is 6667")},
 #endif
 	{"SET", cmd_set, 0, 0, N_("SET <variable> [<value>]")},
-	{"SETTAB", cmd_settab, 0, 0, ""},
+	{"SETTAB", cmd_settab, 0, 0, 0},
 	{"TOPIC", cmd_topic, 1, 1,
 	 N_("TOPIC [<topic>], sets the topic if one is given, else shows the current topic")},
 	{"UNBAN", cmd_unban, 1, 1,
@@ -3054,13 +3073,13 @@ nick_comp_cb (struct User *user, nickdata *data)
 static void
 perform_nick_completion (struct session *sess, char *cmd, char *tbuf)
 {
-	long len;
+	int len;
 	char *space = strchr (cmd, ' ');
 	if (space && space != cmd)
 	{
 		if (((space[-1] == ':') || (space[-1] == prefs.nick_suffix[0])) && (space - 1 != cmd))
 		{
-			len = (long) space - (long) cmd - 1;
+			len = space - cmd - 1;
 			if (len < NICKLEN)
 			{
 				char nick[NICKLEN];
