@@ -27,6 +27,7 @@
 #include "outbound.h"
 #include "cfgfiles.h"
 #include "ignore.h"
+#include "notify.h"
 #include "text.h"
 #define PLUGIN_C
 typedef struct session xchat_context;
@@ -66,7 +67,8 @@ struct _xchat_list
 	int type;			/* LIST_* */
 	GSList *pos;		/* current pos */
 	GSList *next;		/* next pos */
-	GSList *head;
+	GSList *head;		/* for LIST_USERS only */
+	struct notify_per_server *notifyps;	/* notify_per_server * */
 };
 
 typedef int (xchat_cmd_cb) (char *word[], char *word_eol[], void *user_data);
@@ -82,6 +84,7 @@ enum
 	LIST_CHANNELS,
 	LIST_DCC,
 	LIST_IGNORE,
+	LIST_NOTIFY,
 	LIST_USERS
 };
 
@@ -159,7 +162,7 @@ plugin_free (xchat_plugin *pl, int do_deinit, int allow_refuse)
 
 xit:
 	if (pl->filename)
-		free (pl->filename);
+		free ((char *)pl->filename);
 	free (pl);
 
 	plugin_list = g_slist_remove (plugin_list, pl);
@@ -172,8 +175,9 @@ xit:
 }
 
 static xchat_plugin *
-plugin_list_add (xchat_context *ctx, char *filename, char *name, char *desc,
-					  char *version, void *handle, void *deinit_func, int fake)
+plugin_list_add (xchat_context *ctx, char *filename, const char *name,
+					  const char *desc, const char *version, void *handle,
+					  void *deinit_func, int fake)
 {
 	xchat_plugin *pl;
 
@@ -181,9 +185,9 @@ plugin_list_add (xchat_context *ctx, char *filename, char *name, char *desc,
 	pl->handle = handle;
 	pl->filename = filename;
 	pl->context = ctx;
-	pl->name = name;
-	pl->desc = desc;
-	pl->version = version;
+	pl->name = (char *)name;
+	pl->desc = (char *)desc;
+	pl->version = (char *)version;
 	pl->deinit_callback = deinit_func;
 	pl->fake = fake;
 
@@ -250,11 +254,11 @@ plugin_add (session *sess, char *filename, void *handle, void *init_func,
 		pl->xchat_emit_print = xchat_emit_print;
 		/* incase new plugins are loaded on older xchat */
 #ifdef WIN32
-		pl->xchat_dummy8 = (void *) xchat_read_fd;
+		pl->xchat_read_fd = (void *) xchat_read_fd;
 #else
-		pl->xchat_dummy8 = xchat_dummy;
+		pl->xchat_read_fd = xchat_dummy;
 #endif
-		pl->xchat_dummy7 = xchat_dummy;
+		pl->xchat_list_time = xchat_list_time;
 		pl->xchat_dummy6 = xchat_dummy;
 		pl->xchat_dummy5 = xchat_dummy;
 		pl->xchat_dummy4 = xchat_dummy;
@@ -394,7 +398,16 @@ static session *ps;
 static void
 plugin_auto_load_cb (char *filename)
 {
-	plugin_load (ps, filename, NULL);
+	char *pMsg;
+
+	pMsg = plugin_load (ps, filename, NULL);
+	if (pMsg)
+	{
+		PrintText (ps, "AutoLoad failed for: ");
+		PrintText (ps, filename);
+		PrintText (ps, "\n");
+		PrintText (ps, pMsg);
+	}
 }
 
 void
@@ -605,8 +618,8 @@ plugin_fd_cb (GIOChannel *source, GIOCondition condition, xchat_hook *hook)
 /* allocate and add a hook to our list. Used for all 4 types */
 
 static xchat_hook *
-plugin_add_hook (xchat_plugin *pl, int type, int pri, char *name,
-					  char *help_text, void *callb, int timeout, void *userdata)
+plugin_add_hook (xchat_plugin *pl, int type, int pri, const char *name,
+					  const  char *help_text, void *callb, int timeout, void *userdata)
 {
 	xchat_hook *hook;
 
@@ -694,23 +707,23 @@ xchat_unhook (xchat_plugin *ph, xchat_hook *hook)
 }
 
 xchat_hook *
-xchat_hook_command (xchat_plugin *ph, char *name, int pri, xchat_cmd_cb *callb,
-					 	  char *help_text, void *userdata)
+xchat_hook_command (xchat_plugin *ph, const char *name, int pri,
+						  xchat_cmd_cb *callb, const char *help_text, void *userdata)
 {
 	return plugin_add_hook (ph, HOOK_COMMAND, pri, name, help_text, callb, 0,
 									userdata);
 }
 
 xchat_hook *
-xchat_hook_server (xchat_plugin *ph, char *name, int pri, xchat_serv_cb *callb,
-					 	 void *userdata)
+xchat_hook_server (xchat_plugin *ph, const char *name, int pri,
+						 xchat_serv_cb *callb, void *userdata)
 {
 	return plugin_add_hook (ph, HOOK_SERVER, pri, name, 0, callb, 0, userdata);
 }
 
 xchat_hook *
-xchat_hook_print (xchat_plugin *ph, char *name, int pri, xchat_print_cb *callb,
-					   void *userdata)
+xchat_hook_print (xchat_plugin *ph, const char *name, int pri,
+						xchat_print_cb *callb, void *userdata)
 {
 	return plugin_add_hook (ph, HOOK_PRINT, pri, name, 0, callb, 0, userdata);
 }
@@ -737,7 +750,7 @@ xchat_hook_fd (xchat_plugin *ph, int fd, int flags,
 }
 
 void
-xchat_print (xchat_plugin *ph, char *text)
+xchat_print (xchat_plugin *ph, const char *text)
 {
 	if (!is_session (ph->context))
 	{
@@ -745,11 +758,11 @@ xchat_print (xchat_plugin *ph, char *text)
 		return;
 	}
 
-	PrintText (ph->context, text);
+	PrintText (ph->context, (char *)text);
 }
 
 void
-xchat_printf (xchat_plugin *ph, char *format, ...)
+xchat_printf (xchat_plugin *ph, const char *format, ...)
 {
 	va_list args;
 	char *buf;
@@ -763,7 +776,7 @@ xchat_printf (xchat_plugin *ph, char *format, ...)
 }
 
 void
-xchat_command (xchat_plugin *ph, char *command)
+xchat_command (xchat_plugin *ph, const char *command)
 {
 	if (!is_session (ph->context))
 	{
@@ -771,11 +784,11 @@ xchat_command (xchat_plugin *ph, char *command)
 		return;
 	}
 
-	handle_command (ph->context, command, FALSE);
+	handle_command (ph->context, (char *)command, FALSE);
 }
 
 void
-xchat_commandf (xchat_plugin *ph, char *format, ...)
+xchat_commandf (xchat_plugin *ph, const char *format, ...)
 {
 	va_list args;
 	char *buf;
@@ -789,7 +802,7 @@ xchat_commandf (xchat_plugin *ph, char *format, ...)
 }
 
 int
-xchat_nickcmp (xchat_plugin *ph, char *s1, char *s2)
+xchat_nickcmp (xchat_plugin *ph, const char *s1, const char *s2)
 {
 	return ((session *)ph->context)->server->p_cmp (s1, s2);
 }
@@ -812,7 +825,7 @@ xchat_set_context (xchat_plugin *ph, xchat_context *context)
 }
 
 xchat_context *
-xchat_find_context (xchat_plugin *ph, char *servname, char *channel)
+xchat_find_context (xchat_plugin *ph, const char *servname, const char *channel)
 {
 	GSList *slist, *clist;
 	server *serv;
@@ -960,6 +973,12 @@ xchat_list_get (xchat_plugin *ph, const char *name)
 		list->next = ignore_list;
 		break;
 
+	case 0xc2079749:	/* notify */
+		list->type = LIST_NOTIFY;
+		list->next = notify_list;
+		list->head = (void *)ph->context;	/* reuse this pointer */
+		break;
+
 	case 0x6a68e08: /* users */
 		if (is_session (ph->context))
 		{
@@ -992,6 +1011,17 @@ xchat_list_next (xchat_plugin *ph, xchat_list *xlist)
 
 	xlist->pos = xlist->next;
 	xlist->next = xlist->pos->next;
+
+	/* NOTIFY LIST: Find the entry which matches the context
+		of the plugin when list_get was originally called. */
+	if (xlist->type == LIST_NOTIFY)
+	{
+		xlist->notifyps = notify_find_server_entry (xlist->pos->data,
+													((session *)xlist->head)->server);
+		if (!xlist->notifyps)
+			return 0;
+	}
+
 	return 1;
 }
 
@@ -1005,19 +1035,24 @@ xchat_list_fields (xchat_plugin *ph, const char *name)
 	};
 	static const char *channels_fields[] =
 	{
-		"schannel",	"pcontext", "snetwork", "sserver",	"itype",	NULL
+		"schannel",	"pcontext", "iflags", "iid", "snetwork", "sserver",
+		"itype", "iusers", NULL
 	};
 	static const char *ignore_fields[] =
 	{
 		"iflags", "smask", NULL
 	};
+	static const char *notify_fields[] =
+	{
+		"iflags", "snick", "toff", "ton", "tseen", NULL
+	};
 	static const char *users_fields[] =
 	{
 		"iaway", "shost", "snick", "sprefix", NULL
 	};
 	static const char *list_of_lists[] =
 	{
-		"channels",	"dcc", "ignore", "users", NULL
+		"channels",	"dcc", "ignore", "notify", "users", NULL
 	};
 
 	switch (str_hash (name))
@@ -1028,6 +1063,8 @@ xchat_list_fields (xchat_plugin *ph, const char *name)
 		return dcc_fields;
 	case 0xb90bfdd2:	/* ignore */
 		return ignore_fields;
+	case 0xc2079749:	/* notify */
+		return notify_fields;
 	case 0x6a68e08:	/* users */
 		return users_fields;
 	case 0x6236395:	/* lists */
@@ -1037,6 +1074,31 @@ xchat_list_fields (xchat_plugin *ph, const char *name)
 	return NULL;
 }
 
+time_t
+xchat_list_time (xchat_plugin *ph, xchat_list *xlist, const char *name)
+{
+	guint32 hash = str_hash (name);
+/*	gpointer data = xlist->pos->data;*/
+
+	switch (xlist->type)
+	{
+	case LIST_NOTIFY:
+		if (!xlist->notifyps)
+			return (time_t) -1;
+		switch (hash)
+		{
+		case 0x1ad6f:	/* off */
+			return xlist->notifyps->lastoff;
+		case 0xddf:	/* on */
+			return xlist->notifyps->laston;
+		case 0x35ce7b:	/* seen */
+			return xlist->notifyps->lastseen;
+		}
+	}
+
+	return (time_t) -1;
+}
+
 const char *
 xchat_list_str (xchat_plugin *ph, xchat_list *xlist, const char *name)
 {
@@ -1079,6 +1141,14 @@ xchat_list_str (xchat_plugin *ph, xchat_list *xlist, const char *name)
 		}
 		break;
 
+	case LIST_NOTIFY:
+		switch (hash)
+		{
+		case 0x339763: /* nick */
+			return ((struct notify *)data)->name;
+		}
+		break;
+
 	case LIST_USERS:
 		switch (hash)
 		{
@@ -1136,11 +1206,30 @@ xchat_list_int (xchat_plugin *ph, xchat_list *xlist, const char *name)
 	case LIST_CHANNELS:
 		switch (hash)
 		{
+		case 0xd1b:	/* id */
+			return ((struct session *)data)->server->id;
+		case 0x5cfee87:	/* flags */
+			return ((((struct session *)data)->server->connected) & 1) ||
+					 ((((struct session *)data)->server->connecting << 1) & 1) ||
+					 ((((struct session *)data)->server->is_away << 2) & 2) ||
+					 ((((struct session *)data)->server->end_of_motd << 3) & 4) ||
+					 ((((struct session *)data)->server->have_whox << 4) & 8);
 		case 0x368f3a:	/* type */
 			return ((struct session *)data)->type;
+		case 0x6a68e08: /* users */
+			return ((struct session *)data)->total;
 		}
 		break;
 
+	case LIST_NOTIFY:
+		if (!xlist->notifyps)
+			return -1;
+		switch (hash)
+		{
+		case 0x5cfee87: /* flags */
+			return xlist->notifyps->ison;
+		}
+
 	case LIST_USERS:
 		switch (hash)
 		{
@@ -1155,8 +1244,9 @@ xchat_list_int (xchat_plugin *ph, xchat_list *xlist, const char *name)
 }
 
 void *
-xchat_plugingui_add (xchat_plugin *ph, char *filename, char *name, char *desc,
-							char *version, char *reserved)
+xchat_plugingui_add (xchat_plugin *ph, const char *filename,
+							const char *name, const char *desc,
+							const char *version, char *reserved)
 {
 #ifdef USE_PLUGIN
 	ph = plugin_list_add (NULL, strdup (filename), name, desc, version, NULL,
@@ -1176,7 +1266,7 @@ xchat_plugingui_remove (xchat_plugin *ph, void *handle)
 }
 
 int
-xchat_emit_print (xchat_plugin *ph, char *event_name, ...)
+xchat_emit_print (xchat_plugin *ph, const char *event_name, ...)
 {
 	va_list args;
 	char *argv[4] = {NULL, NULL, NULL, NULL};
@@ -1194,7 +1284,7 @@ xchat_emit_print (xchat_plugin *ph, char *event_name, ...)
 			break;
 	}
 
-	i = text_emit_by_name (event_name, ph->context, argv[0], argv[1],
+	i = text_emit_by_name ((char *)event_name, ph->context, argv[0], argv[1],
 								  argv[2], argv[3]);
 	va_end (args);
 
