@@ -1,21 +1,24 @@
+#ifndef XCHAT_COMMONPLUGIN_H
+#define XCHAT_COMMONPLUGIN_H
+
 #ifdef PLUGIN_C
 struct _xchat_plugin
 {
 	/* Keep these insync with xchat-plugin.h */
 	/* !!don't change the order, to keep binary compat!! */
 	xchat_hook *(*xchat_hook_command) (xchat_plugin *ph,
-		    char *name,
+		    const char *name,
 		    int pri,
 		    int (*callback) (char *word[], char *word_eol[], void *user_data),
-		    char *help_text,
+		    const char *help_text,
 		    void *userdata);
 	xchat_hook *(*xchat_hook_server) (xchat_plugin *ph,
-		   char *name,
+		   const char *name,
 		   int pri,
 		   int (*callback) (char *word[], char *word_eol[], void *user_data),
 		   void *userdata);
 	xchat_hook *(*xchat_hook_print) (xchat_plugin *ph,
-		  char *name,
+		  const char *name,
 		  int pri,
 		  int (*callback) (char *word[], void *user_data),
 		  void *userdata);
@@ -31,21 +34,21 @@ struct _xchat_plugin
 	void *(*xchat_unhook) (xchat_plugin *ph,
 	      xchat_hook *hook);
 	void (*xchat_print) (xchat_plugin *ph,
-	     char *text);
+	     const char *text);
 	void (*xchat_printf) (xchat_plugin *ph,
-	      char *format, ...);
+	      const char *format, ...);
 	void (*xchat_command) (xchat_plugin *ph,
-	       char *command);
+	       const char *command);
 	void (*xchat_commandf) (xchat_plugin *ph,
-		char *format, ...);
+		const char *format, ...);
 	int (*xchat_nickcmp) (xchat_plugin *ph,
-	       char *s1,
-	       char *s2);
+	       const char *s1,
+	       const char *s2);
 	int (*xchat_set_context) (xchat_plugin *ph,
 		   xchat_context *ctx);
 	xchat_context *(*xchat_find_context) (xchat_plugin *ph,
-		    char *servname,
-		    char *channel);
+		    const char *servname,
+		    const char *channel);
 	xchat_context *(*xchat_get_context) (xchat_plugin *ph);
 	const char *(*xchat_get_info) (xchat_plugin *ph,
 		const char *id);
@@ -68,17 +71,19 @@ struct _xchat_plugin
 		xchat_list *xlist,
 		const char *name);
 	void * (*xchat_plugingui_add) (xchat_plugin *ph,
-		     char *filename,
-		     char *name,
-		     char *desc,
-		     char *version,
+		     const char *filename,
+		     const char *name,
+		     const char *desc,
+		     const char *version,
 		     char *reserved);
 	void (*xchat_plugingui_remove) (xchat_plugin *ph,
 			void *handle);
 	int (*xchat_emit_print) (xchat_plugin *ph,
-			char *event_name, ...);
-	void (*xchat_dummy8) (xchat_plugin *ph);
-	void (*xchat_dummy7) (xchat_plugin *ph);
+			const char *event_name, ...);
+	void (*xchat_read_fd) (xchat_plugin *ph);
+	time_t (*xchat_list_time) (xchat_plugin *ph,
+		xchat_list *xlist,
+		const char *name);
 	void (*xchat_dummy6) (xchat_plugin *ph);
 	void (*xchat_dummy5) (xchat_plugin *ph);
 	void (*xchat_dummy4) (xchat_plugin *ph);
@@ -107,3 +112,5 @@ int plugin_emit_server (session *sess, char *name, char *word[], char *word_eol[
 int plugin_emit_print (session *sess, char *word[]);
 int plugin_emit_dummy_print (session *sess, char *name);
 int plugin_show_help (session *sess, char *cmd);
+
+#endif
