@@ -601,6 +601,10 @@ fe_set_hilight (struct session *sess)
 {
 }
 void
+fe_set_tab_color (struct session *sess, int col, int flash)
+{
+}
+void
 fe_update_mode_buttons (struct session *sess, char mode, char sign)
 {
 }
@@ -721,7 +725,7 @@ fe_dlgbuttons_update (struct session *sess)
 {
 }
 void
-fe_dcc_send_filereq (struct session *sess, char *nick, int maxcps)
+fe_dcc_send_filereq (struct session *sess, char *nick, int maxcps, int passive)
 {
 }
 void
@@ -800,6 +804,9 @@ fe_idle_add (void *func, void *data)
 {
 }
 void
-fe_ctrl_gui (session *sess, int action)
+fe_ctrl_gui (session *sess, int action, int arg)
+{
+}
+void fe_confirm (const char *message, void (*yesproc)(void *), void (*noproc)(void *), void *ud)
 {
 }
